summaryrefslogtreecommitdiff
path: root/cups/http.h
diff options
context:
space:
mode:
authormsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2009-05-08 18:38:44 +0000
committermsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2009-05-08 18:38:44 +0000
commitf11a948a02771f78f50b530880a0269d4b4f58eb (patch)
tree46f42695fc19300726483f4ad9ca0ecddeb50a16 /cups/http.h
parente07d4801f9846b9155d4c63872f51b18d8537d01 (diff)
downloadcups-f11a948a02771f78f50b530880a0269d4b4f58eb.tar.gz
Merge changes from CUPS 1.4svn-r8606.
git-svn-id: svn+ssh://src.apple.com/svn/cups/easysw/current@1480 a1ca3aef-8c08-0410-bb20-df032aa958be
Diffstat (limited to 'cups/http.h')
-rw-r--r--cups/http.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/cups/http.h b/cups/http.h
index 0c51578d7..70ffe4d3a 100644
--- a/cups/http.h
+++ b/cups/http.h
@@ -248,7 +248,10 @@ typedef enum http_status_e /**** HTTP status codes ****/
HTTP_BAD_GATEWAY, /* Bad gateway */
HTTP_SERVICE_UNAVAILABLE, /* Service is unavailable */
HTTP_GATEWAY_TIMEOUT, /* Gateway connection timed out */
- HTTP_NOT_SUPPORTED /* HTTP version not supported */
+ HTTP_NOT_SUPPORTED, /* HTTP version not supported */
+
+ HTTP_AUTHORIZATION_CANCELED = 1000 /* User cancelled authorization */
+
} http_status_t;
typedef enum http_uri_status_e /**** URI separation status @since CUPS1.2@ ****/